@@ -4,6 +4,8 @@ from limits import storage, RateLimitItemPerSecond
 from limits import strategies
 
 memcached_storage = storage.MemcachedStorage("memcached://localhost:22122")
+# Flush memcached in case we are testing multiple Python versions in a row
+memcached_storage.storage.flush_all()
 
 fixed_window = strategies.FixedWindowRateLimiter(memcached_storage)
 
